| IndZonas | R Documentation |
Estimation of global indices by areas; merely a wrapper around ConsInd.
IndZonas(datos, zonas, frm = NULL, base = "2008-01-01", plot = FALSE)
datos |
Dataframe of observations |
zonas |
Name of the column of |
frm |
Formula specifying the base model, in the notation expected by |
base |
Base date (index=100). It is a day in format yyyy-mm-dd. |
plot |
|
A list with the computed indices, in the format in which they are returned by ConsInd.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.