| cloromap | R Documentation |
Given a spatail dataframe, creates a cloropleth map from the valaues of one of the variables in the @data slot
cloromap( sp, var.sp, df, var.df, var, sub.var = NULL, sub.set = NULL, legend.title = NULL, logcolor = FALSE, graf.title = NULL, ... )
sp |
Spatial dataframe, in whose @data slot variable |
var.sp |
Variable whose values specify the spatail aggregation. |
df |
Ordinary dataframe with variable |
var.df |
Variable matching |
var |
Variable to code with color. Must be a column of |
sub.var |
Variable in |
sub.set |
Vector of values of |
legend.title |
Legend heading |
logcolor |
FALSE if linear color scale, TRUE if logarithmic. |
graf.title |
Heading of the graph. |
... |
Optional additional parameters to pass to the underlying |
A map, of ggplot2 format, printed by default.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.